import csv
import xml.etree.ElementTree as ET
import requests
from decimal import Decimal, ROUND_HALF_UP

# URL of the XML file
xml_url = 'https://strefasupli.pl/storage/exports/ceneo.xml'

# Define the output CSV file
csv_file = 'strefasupli.csv'

# Prefix for the product ID
id_prefix = 'strefasupli_'

# Multiplier for the price
price_multiplier = Decimal('1.1')

# Download the XML file
response = requests.get(xml_url, stream = True, headers={'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36'})
xml_data = response.content

# Parse the XML data
root = ET.fromstring(xml_data)

# Open the CSV file in write mode
with open(csv_file, 'w', newline='') as f:
    writer = csv.writer(f)

    # Write the header row
    writer.writerow(['sku', 'price', 'qty'])

    # Iterate over each 'o' element in the XML
    for product in root.findall('.//o'):

        # Extract the required data attributes
        product_id = product.get('id')
        price = product.get('price')

        # Add the prefix to the product ID
        product_id = id_prefix + product_id

        if 'stock' in product.attrib:
            stock = product.get('stock')
        else:
            stock = '0'
        
        # Write the data row
        writer.writerow([product_id, str(price), stock])

print(f"Product data extracted and saved to '{csv_file}'.")